diff --git a/src/sbbs3/prntfile.cpp b/src/sbbs3/prntfile.cpp
index a3735f63f0fb3e942a6d12b8c036fddb9e8d4bc9..53239bb8b19353a551db10c0ddffb4ebf650c85b 100644
--- a/src/sbbs3/prntfile.cpp
+++ b/src/sbbs3/prntfile.cpp
@@ -290,10 +290,11 @@ bool sbbs_t::menu_exists(const char *code, const char* ext, char* path)
 		return fexistcase(path) ? true : false;
 	}
 
 	/* Either <menu>.asc or <menu>.msg is required */
 	if(ext == NULL)
 		return menu_exists(code, "asc", path)
-			|| menu_exists(code, "msg", path);
+			|| menu_exists(code, "msg", path)
+			|| menu_exists(code, "ans", path);
 
 	char prefix[MAX_PATH];
 	if(isfullpath(code))
@@ -290,10 +290,11 @@ bool sbbs_t::menu_exists(const char *code, const char* ext, char* path)
 	}
 
-	/* Either <menu>.asc or <menu>.msg is required */
+	/* Either <menu>.asc or <menu>.msg or <menu>.ans is required */
 	if(ext == NULL)
 		return menu_exists(code, "asc", path)